# -*- coding: utf-8 -*-

"""TextToSpeech module.

Contains QtTextToSpeech-based classes
"""

from .voice import Voice
from .texttospeech import TextToSpeech

__all__ = [
    "Voice",
    "TextToSpeech",
]
