# -*- coding: utf-8 -*-

"""svg module.

contains QtSvg-based classes
"""

from .graphicssvgitem import GraphicsSvgItem
from .svggenerator import SvgGenerator


__all__ = ["GraphicsSvgItem", "SvgGenerator"]
